### Options avancées

Cette section est destinée aux utilisateurs avancés de ce logiciel. Vous y trouverez :

1. [**Options avancées**](./advanced.md)
<br>
Dans cette section, vous pouvez explorer la spécification des langues source/cible, changer de services de traduction, et plus encore.

2. [**Code de langue**](./Language-Codes.md)
<br>
Si vous ne savez pas quels codes utiliser pour traduire vos langues source/cible, vous pouvez les trouver ici.

3. [**Documentation des services de traduction**](./Documentation-des-services-de-traduction.md)
<br>
Si vous avez besoin de consulter la documentation fournie par les services de traduction que vous utilisez, veuillez vous référer à cette page.

<div align="right"> 
<h6><small>Une partie du contenu de cette page a été traduite par GPT et peut contenir des erreurs.</small></h6>